@@ -12,7 +12,7 @@ import pkgutil
 import re
 import json
 
-__version__ = "0.7.2"
+__version__ = "0.7.3"
 
 
 class IfState():
@@ -116,13 +116,16 @@ class IfState():
         while len(applied) < len(self.links):
             last = len(applied)
             for name, link in self.links.items():
+                if name in applied:
+                    continue
+
                 if link is None:
                     logger.debug('skipped due to no link settings',
                                  extra={'iface': name})
                     applied.append(name)
                 else:
-                    dep = link.depends()
-                    if dep is None or dep in applied:
+                    deps = link.depends()
+                    if all(x in applied for x in deps):
                         self.sysctl.apply(name, do_apply)
                         link.apply(do_apply)
                         applied.append(name)
