@@ -196,7 +196,11 @@ class Link(ABC):
             " ".join("{}={}".format(k, v) for k, v in self.settings.items())))
         if do_apply:
             try:
+                state = self.settings.pop('state', None)
                 ipr.link('add', **(self.settings))
+                self.idx = next(iter(ipr.link_lookup(ifname=self.settings['ifname'])), None)
+                if not state is None and not self.idx is None:
+                    ipr.link('set', index=self.idx, state=state)
             except NetlinkError as err:
                 logger.warning('adding link {} failed: {}'.format(
                     self.settings['ifname'], err.args[1]))
@@ -274,7 +278,10 @@ class Link(ABC):
                             'iface': self.settings['ifname'], 'style': LogStyle.CHG})
             if do_apply:
                 try:
+                    state = self.settings.pop('state', None)
                     ipr.link('set', index=self.idx, **(self.settings))
+                    if not state is None:
+                        ipr.link('set', index=self.idx, state=state)
                 except NetlinkError as err:
                     logger.warning('updating link {} failed: {}'.format(
                         self.settings['ifname'], err.args[1]))
@@ -285,7 +292,11 @@ class Link(ABC):
                 'ok', extra={'iface': self.settings['ifname'], 'style': LogStyle.OK})
 
     def depends(self):
-        return None
+        deps = []
+        for attr in self.attr_idx:
+            if attr in self.settings:
+                deps.append(self.settings[attr])
+        return deps
 
     @classmethod
     def name2nla(self, name):
